#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tar-z-tar-internal
version:              0.6.0.0
package-name:         tar
lib-name:             tar-internal
id:                   tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal
key:                  tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal
license:              BSD-3-Clause
copyright:
    2007 Bjorn Bringert <bjorn@bringert.net>
    2008-2016 Duncan Coutts <duncan@community.haskell.org>

maintainer:           Bodigrim <andrew.lelechenko@gmail.com>
author:
    Duncan Coutts <duncan@community.haskell.org>
    Bjorn Bringert <bjorn@bringert.net>

synopsis:             Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.

    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.

    It also provides features for random access to archive
    content using an index.

category:             Codec
abi:                  3678fd64ee28d99f760324eaeadf69cc
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check
    Codec.Archive.Tar.Check.Internal Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index Codec.Archive.Tar.Index.IntTrie
    Codec.Archive.Tar.Index.Internal
    Codec.Archive.Tar.Index.StringTable Codec.Archive.Tar.LongNames
    Codec.Archive.Tar.Pack Codec.Archive.Tar.PackAscii
    Codec.Archive.Tar.Read Codec.Archive.Tar.Types
    Codec.Archive.Tar.Unpack Codec.Archive.Tar.Write

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tar-0.6.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tar-0.6.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tar-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar
hs-libraries:         HStar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html:         /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               tar
version:            0.6.0.0
visibility:         public
id:                 tar-0.6.0.0-4WxIoFZZ5TgJPpjlO72Id3
key:                tar-0.6.0.0-4WxIoFZZ5TgJPpjlO72Id3
license:            BSD-3-Clause
copyright:
    2007 Bjorn Bringert <bjorn@bringert.net>
    2008-2016 Duncan Coutts <duncan@community.haskell.org>

maintainer:         Bodigrim <andrew.lelechenko@gmail.com>
author:
    Duncan Coutts <duncan@community.haskell.org>
    Bjorn Bringert <bjorn@bringert.net>

synopsis:           Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.

    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.

    It also provides features for random access to archive
    content using an index.

category:           Codec
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
exposed-modules:
    Codec.Archive.Tar from tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal:Codec.Archive.Tar,
    Codec.Archive.Tar.Check from tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal:Codec.Archive.Tar.Check,
    Codec.Archive.Tar.Entry from tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal:Codec.Archive.Tar.Entry,
    Codec.Archive.Tar.Index from tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal:Codec.Archive.Tar.Index

data-dir:           /usr/share/haskell-tar
depends:            tar-0.6.0.0-7JB1Ef5IhHI392783WgZbr-tar-internal
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html:       /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

